@@ -50,15 +50,15 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("koko");
-    app.setApplicationDisplayName("Koko");
-    app.setOrganizationDomain("kde.org");
 
     KAboutData aboutData(QStringLiteral("koko"),
                          xi18nc("@title", "<application>Koko</application>"),
                          QStringLiteral(KOKO_VERSION_STRING),
                          xi18nc("@title", "Koko is an image viewer for your image collection."),
                          KAboutLicense::LGPL,
-                         xi18nc("@info:credit", "(c) 2013-2020 KDE Contributors"));
+                         xi18nc("@info:credit", "(c) 2013-2020 KDE Contributors"),
+                         QString(),
+                         QStringLiteral("https://apps.kde.org/koko"));
 
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.setProductName(QByteArray("koko"));
@@ -78,10 +78,7 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(aboutData);
 
-    KLocalizedString::setApplicationDomain("koko");
-
     QCommandLineParser parser;
-    parser.setApplicationDescription(i18n("Image viewer"));
     parser.addOption(QCommandLineOption("reset", i18n("Reset the database")));
     parser.addPositionalArgument("image", i18n("path of image you want to open"));
 
@@ -89,10 +86,6 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    QApplication::setApplicationName(aboutData.componentName());
-    QApplication::setApplicationDisplayName(aboutData.displayName());
-    QApplication::setOrganizationDomain(aboutData.organizationDomain());
-    QApplication::setApplicationVersion(aboutData.version());
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("koko")));
 
     if (parser.isSet("reset") || ImageStorage::shouldReset()) {
